@@ -8,6 +8,8 @@ pub use debug::*;
 #[cfg(feature = "fancy")]
 pub use graphical::*;
 #[allow(unreachable_pub)]
+pub use json::*;
+#[allow(unreachable_pub)]
 pub use narratable::*;
 #[allow(unreachable_pub)]
 #[cfg(feature = "fancy")]
@@ -16,6 +18,7 @@ pub use theme::*;
 mod debug;
 #[cfg(feature = "fancy")]
 mod graphical;
+mod json;
 mod narratable;
 #[cfg(feature = "fancy")]
 mod theme;
